AddEntry

Struct AddEntry 

pub struct AddEntry<'a> {
    pub whitelist_account: &'a AccountInfo,
    pub whitelist_authority: &'a AccountInfo,
    pub whitelist_entry_account: &'a AccountInfo,
    pub payer: &'a AccountInfo,
    pub system_program: &'a AccountInfo,
    pub program_authority: Pubkey,
}
Adds an address to the program whitelist or unrevokes a previously revoked address. If the whitelist_entry_account does not exist, this instruction creates and initializes it. If the account already exists and is marked as revoked, this instruction marks it as active again.

Accounts:

  1. [] The whitelist account (Used for validation/derivation)
  2. [SIGNER] The whitelist authority
  3. [WRITE] The whitelist entry account to be created/initialized or updated
  4. [WRITE, SIGNER] Payer account (must be a system account)
  5. [] System program

Fields

whitelist_account: &'a AccountInfo

The whitelist account (Used for validation/derivation)

whitelist_authority: &'a AccountInfo

The whitelist authority

whitelist_entry_account: &'a AccountInfo

The whitelist entry account to be created/initialized or updated

payer: &'a AccountInfo

Payer account (must be a system account)

system_program: &'a AccountInfo

System program

program_authority: Pubkey

program authority public key

Implementations

Source

impl<'a> AddEntry<'a>

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers: &[Signer<'_, '_>]) -> ProgramResult