pub fn load<T: Pod + Initializable>(input: &[u8]) -> Result<&T, ProgramError>Expand description
Load a reference for an initialized T from the given bytes
pub fn load<T: Pod + Initializable>(input: &[u8]) -> Result<&T, ProgramError>Load a reference for an initialized T from the given bytes