pub fn load_mut<T: Pod + Initializable>(
input: &mut [u8],
) -> Result<&mut T, ProgramError>Expand description
Load a mutable reference for an initialized T from the given bytes
pub fn load_mut<T: Pod + Initializable>(
input: &mut [u8],
) -> Result<&mut T, ProgramError>Load a mutable reference for an initialized T from the given bytes