ProgramWhitelistInstruction

Enum ProgramWhitelistInstruction 

#[repr(C)]
pub enum ProgramWhitelistInstruction { CreateWhitelist {}, InitiateAuthorityTransfer { new_authority: Pubkey, }, AcceptAuthorityTransfer, CancelAuthorityTransfer {}, AddEntry { program_authority: Pubkey, }, RemoveEntry { program_authority: Pubkey, }, }
Instructions supported by the program whitelist program.

Variants



CreateWhitelist

Initializes the program whitelist account, setting its initial state with the initial authority.

Accounts expected by this instruction:

  1. [writable] The whitelist account to initialize
  2. [signer] The authority that will control the whitelist
  3. [signer] Account that will pay for the account creation
  4. [] The system program


InitiateAuthorityTransfer

Proposes a new authority for the program whitelist. The current whitelist_authority must sign this instruction. The proposed new_authority must then sign an AcceptAuthorityTransfer instruction to finalize the transfer.

Accounts expected by this instruction:

  1. [writable] The whitelist account
  2. [signer] The current whitelist authority

Fields

new_authority: Pubkey


AcceptAuthorityTransfer

Accepts the pending authority transfer for the program whitelist. The pending_whitelist_authority must sign this instruction to assume authority over the whitelist.

Accounts expected by this instruction:

  1. [writable] The whitelist account
  2. [signer] The pending whitelist authority


CancelAuthorityTransfer

Cancels a pending authority transfer for the program whitelist. The current whitelist_authority must sign this instruction.

Accounts expected by this instruction:

  1. [writable] The whitelist account
  2. [signer] The current whitelist authority


AddEntry

Adds an address to the program whitelist or unrevokes a previously revoked address. If the whitelist_entry_account does not exist, this instruction creates and initializes it. If the account already exists and is marked as revoked, this instruction marks it as active again. The whitelist_authority must sign.

Accounts expected by this instruction:

  1. [] The whitelist account (Used for validation/derivation)
  2. [signer] The whitelist authority
  3. [writable] The whitelist entry account to be created/initialized or updated
  4. [writable, signer] Payer account (must be a system account)
  5. [] System program

Fields

program_authority: Pubkey


RemoveEntry

Closes a specific whitelist entry account, transferring its rent lamports to a designated destination account. The whitelist_authority must sign this instruction.

Accounts expected by this instruction:

  1. [] The whitelist account (Used for validation)
  2. [signer] The whitelist authority
  3. [writable] The whitelist entry account to close
  4. [writable] The destination account for reclaimed lamports
  5. [] System program

Fields

program_authority: Pubkey

Implementations

Source

impl ProgramWhitelistInstruction

pub fn unpack(input: &[u8]) -> Result<Self, ProgramError>

Unpack a program whitelist instruction from a byte slice.