pub struct AddEntry<'a> {
pub whitelist_account: &'a AccountInfo,
pub whitelist_authority: &'a AccountInfo,
pub whitelist_entry_account: &'a AccountInfo,
pub payer: &'a AccountInfo,
pub system_program: &'a AccountInfo,
pub program_authority: Pubkey,
}Expand description
Adds an address to the program whitelist or unrevokes a previously revoked
address. If the whitelist_entry_account does not exist, this
instruction creates and initializes it. If the account already exists
and is marked as revoked, this instruction marks it as active again.
Accounts:
[]The whitelist account (Used for validation/derivation)[SIGNER]The whitelist authority[WRITE]The whitelist entry account to be created/initialized or updated[WRITE, SIGNER]Payer account (must be a system account)[]System program
Fields
whitelist_account: &'a AccountInfoThe whitelist account (Used for validation/derivation)
The whitelist authority
whitelist_entry_account: &'a AccountInfoThe whitelist entry account to be created/initialized or updated
payer: &'a AccountInfoPayer account (must be a system account)
system_program: &'a AccountInfoSystem program
program authority public key
Implementations
Sourceimpl<'a> AddEntry<'a>
impl<'a> AddEntry<'a>
pub fn invoke(&self) -> ProgramResult
pub fn invoke_signed(&self, signers: &[Signer<'_, '_>]) -> ProgramResult