pub fn load_mut<'data, T: Pod + Initializable>(
input: &'data mut [u8],
) -> Result<&'data mut T, ProgramError>Expand description
Load a mutable reference for an initialized T from the given bytes
pub fn load_mut<'data, T: Pod + Initializable>(
input: &'data mut [u8],
) -> Result<&'data mut T, ProgramError>Load a mutable reference for an initialized T from the given bytes